#ifndef _CONFIG_H

#define _CONFIG_H

#undef VERSION 
#undef PACKAGE
#undef HAVE_LIBPNG  

#undef HAVE_LIBSDL

#undef HAVE_SMPEG

#undef HAVE_MIXER

#undef HAVE_FREETYPE

#undef HAVE_STD_HASHMAP

#undef HAVE_GNU_CXX_HASHMAP

#undef HAVE_STD_SLIST

#undef HAVE_GNU_CXX_SLIST

#endif
